@@ -16,15 +16,51 @@ See :doc:`contextvars`.
 
 import contextvars
 
-from typing import Any, Dict
+from typing import Any, Dict, Mapping
 
-from .types import EventDict, WrappedLogger
+import structlog
+
+from .types import BindableLogger, EventDict, WrappedLogger
 
 
 STRUCTLOG_KEY_PREFIX = "structlog_"
+STRUCTLOG_KEY_PREFIX_LEN = len(STRUCTLOG_KEY_PREFIX)
+
+# For proper isolation, we have to use a dict of ContextVars instead of a
+# single ContextVar with a dict.
+# See https://github.com/hynek/structlog/pull/302 for details.
 _CONTEXT_VARS: Dict[str, contextvars.ContextVar[Any]] = {}
 
 
+def get_contextvars() -> Dict[str, Any]:
+    """
+    Return a copy of the ``structlog``-specific context-local context.
+
+    .. versionadded:: 21.2.0
+    """
+    rv = {}
+    ctx = contextvars.copy_context()
+
+    for k in ctx:
+        if k.name.startswith(STRUCTLOG_KEY_PREFIX) and ctx[k] is not Ellipsis:
+            rv[k.name[STRUCTLOG_KEY_PREFIX_LEN:]] = ctx[k]
+
+    return rv
+
+
+def get_merged_contextvars(bound_logger: BindableLogger) -> Dict[str, Any]:
+    """
+    Return a copy of the current context-local context merged with the context
+    from *bound_logger*.
+
+    .. versionadded:: 21.2.0
+    """
+    ctx = get_contextvars()
+    ctx.update(structlog.get_context(bound_logger))
+
+    return ctx
+
+
 def merge_contextvars(
     logger: WrappedLogger, method_name: str, event_dict: EventDict
 ) -> EventDict:
@@ -41,7 +77,7 @@ def merge_contextvars(
 
     for k in ctx:
         if k.name.startswith(STRUCTLOG_KEY_PREFIX) and ctx[k] is not Ellipsis:
-            event_dict.setdefault(k.name[len(STRUCTLOG_KEY_PREFIX) :], ctx[k])
+            event_dict.setdefault(k.name[STRUCTLOG_KEY_PREFIX_LEN:], ctx[k])
 
     return event_dict
 
@@ -62,16 +98,22 @@ def clear_contextvars() -> None:
             k.set(Ellipsis)
 
 
-def bind_contextvars(**kw: Any) -> None:
-    """
+def bind_contextvars(**kw: Any) -> "Mapping[str, contextvars.Token[Any]]":
+    r"""
     Put keys and values into the context-local context.
 
     Use this instead of :func:`~structlog.BoundLogger.bind` when you want some
     context to be global (context-local).
 
+    Return the mapping of ``contextvars.Token``\s resulting
+    from setting the backing ``ContextVar``\s.
+    Suitable for passing to :func:`reset_contextvars`.
+
     .. versionadded:: 20.1.0
-    .. versionchanged:: 21.1.0 See toplevel note.
+    .. versionchanged:: 21.1.0 Return the ``contextvars.Token`` mapping
+        rather than None. See also the toplevel note.
     """
+    rv = {}
     for k, v in kw.items():
         structlog_k = f"{STRUCTLOG_KEY_PREFIX}{k}"
         try:
@@ -80,7 +122,21 @@ def bind_contextvars(**kw: Any) -> None:
             var = contextvars.ContextVar(structlog_k, default=Ellipsis)
             _CONTEXT_VARS[structlog_k] = var
 
-        var.set(v)
+        rv[k] = var.set(v)
+
+    return rv
+
+
+def reset_contextvars(**kw: "contextvars.Token[Any]") -> None:
+    r"""
+    Reset contextvars corresponding to the given Tokens.
+
+    .. versionadded:: 21.1.0
+    """
+    for k, v in kw.items():
+        structlog_k = f"{STRUCTLOG_KEY_PREFIX}{k}"
+        var = _CONTEXT_VARS[structlog_k]
+        var.reset(v)
 
 
 def unbind_contextvars(*keys: str) -> None:
