@@ -57,7 +57,7 @@ class KeyValueRenderer:
     :param drop_missing: When ``True``, extra keys in *key_order* will be
         dropped rather than rendered as ``None``.
     :param repr_native_str: When ``True``, :func:`repr()` is also applied
-        to native strings (i.e. unicode on Python 3 and bytes on Python 2).
+        to native strings.
         Setting this to ``False`` is useful if you want to have human-readable
         non-ASCII output on Python 2.
 
@@ -106,7 +106,7 @@ class KeyValueRenderer:
                 return sorted(event_dict.items())
 
         else:
-            ordered_items = operator.methodcaller("items")
+            ordered_items = operator.methodcaller("items")  # type: ignore
 
         self._ordered_items = ordered_items
 
@@ -267,8 +267,7 @@ def format_exc_info(
     behaviors:
 
     - If the value is a tuple, render it into the key ``exception``.
-    - If the value is an Exception *and* you're running Python 3, render it
-      into the key ``exception``.
+    - If the value is an Exception render it into the key ``exception``.
     - If the value true but no tuple, obtain exc_info ourselves and render
       that.
 
@@ -391,7 +390,7 @@ class ExceptionPrettyPrinter:
     This processor is mostly for development and testing so you can read
     exceptions properly formatted.
 
-    It behaves like format_exc_info` except it removes the exception
+    It behaves like `format_exc_info` except it removes the exception
     data from the event dictionary after printing it.
 
     It's tolerant to having `format_exc_info` in front of itself in the
@@ -433,7 +432,7 @@ class StackInfoRenderer:
     involving an exception.
 
     It works analogously to the *stack_info* argument of the Python 3 standard
-    library logging but works on both 2 and 3.
+    library logging.
 
     .. versionadded:: 0.4.0
     """
