@@ -319,7 +319,7 @@ class BoundLogger(BoundLoggerBase):
         """
         Calls :meth:`logging.Logger.callHandlers` with unmodified arguments.
         """
-        self._logger.callHandlers(record)  # type: ignore
+        self._logger.callHandlers(record)
 
     def getEffectiveLevel(self) -> int:
         """
@@ -367,13 +367,6 @@ class AsyncBoundLogger:
     the processor chain (e.g. JSON serialization) and I/O won't block your
     whole application.
 
-    .. warning: Since the processor pipeline runs in a separate thread,
-        `structlog.contextvars.merge_contextvars` does **nothing** and should
-        be removed from you processor chain.
-
-        Instead it's merged within **this logger** before handing off log
-        processing to the thread.
-
     Only available for Python 3.7 and later.
 
     :ivar structlog.stdlib.BoundLogger sync_bl: The wrapped synchronous logger.
@@ -426,7 +419,7 @@ class AsyncBoundLogger:
     def bind(self, **new_values: Any) -> "AsyncBoundLogger":
         return AsyncBoundLogger(
             # logger, processors and context are within sync_bl. These
-            # arguments are ignored if _sync_bl is passsed. *vroom vroom* over
+            # arguments are ignored if _sync_bl is passed. *vroom vroom* over
             # purity.
             logger=None,  # type: ignore
             processors=(),
